function E = computePlaneE(sourcePowers, sourcePhases, R, Z0, k, time, freq)
%% computePlaneE compute electric field from electromagnetic plane wave.
% Computation does not include free space losses! Field strength does not drop
% according to distance, just a phase is evolving. Resulting field strength has
% the same value as voltage across Z0 impedance.
%
%  INPUTS:
%   sourcePowers: powers of sources in watts, double [1 x 1 x N]
%   sourcePhases: phases of radiated field at zero time in radians, double [1 x 1 x N]
%   R: distances of points from sources in meters, double [K x L x N]
%   Z0: impedance of free space, double [1 x 1]
%   k: wave number, radians/m, double [1 x 1]
%   time: time in seconds when to compute field state, double [1 x 1]
%   freq: frequency of source signal, double [1 x 1]
%
%  OUTPUTS:
%   E: electric field in V/m in 2D cut, complex double [K x L]
%
% © 2020, Viktor Adler, CTU in Prague, adlervik@fel.cvut.cz

E0 = sqrt(2*sourcePowers.*Z0);
E = sum(E0.*exp(1j*(-k*R + sourcePhases + 2*pi*freq*time)), 3);
end