function R = computePlaneR(origin, sourceAzimuths, k, X, Y)
%% computePlaneR computes oriented distances between set of points and plane wavefront.
%
%  INPUTS:
%   origin: coordinates of origin of coordinate system in form [x, y], double [1 x 2]
%   sourceAzimuths: azimuths in radians from which travels plane waves, double [1 x 1 x N]
%   k: wave number, radians/m, double [1 x 1]
%   X, Y: coordinates of set of points, double [J x 1], [1 x K]
%
%  OUTPUTS:
%   R: distance between set of points and wavefront of plane wave, double [J x K x N]
%
% © 2020, Viktor Adler, CTU in Prague, adlervik@fel.cvut.cz

kx = -k*sin(sourceAzimuths);
ky = -k*cos(sourceAzimuths);
d = -(kx*origin(1) + ky*origin(2));
R = (kx.*X + ky.*Y + d)./sqrt(kx.^2 + ky.^2);
end